<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as AR_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	 exit; // Exit if accessed directly.
}

/**
 * Skin for Hero Style 1.
 */
class Hero_Style_1 extends Skin_Base {

	 /**
	  * Get the name of the widget.
	  *
	  * @return string
	  */
	public function get_id() {
		return 'hero-caorusel-1';
	}

	 /**
	  * Get the title of the skin.
	  *
	  * @return string
	  */
	public function get_title() {
		return esc_html__( 'Hero Carousel 1', 'hellix-elementor' );
	}

	 /**
	  * Register Controls Action.
	  */
	protected function _register_controls_actions() {
		add_action( 'elementor/element/hx-hero-carousel/section_slides/after_section_end', [ $this, 'add_controls' ], 10 );
	}

	 /**
	  * Update controls for removing column and caption controls.
	  *
	  * @param Elementor\Widget_Base $widget The widget settings.
	  */
	public function add_controls( $widget ) {
		$this->parent = $widget;
		$this->start_controls_section(
			'section_style_1',
			[
				'label' => esc_html__( 'Icon', 'hellix-elementor' ),

			]
		);
		$repeater = new Repeater();

		$repeater->add_control(
			'selected_item_icon',
			[
				'label'   => esc_html__( 'Social Icon', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( '.Facebook', 'hellix-elementor' ),

			]
		);

		$repeater->add_control(
			'selected_icon_class',
			[
				'label'       => esc_html__( 'CSS', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter Your Class', 'hellix-elementor' ),
				'default'     => esc_html__( 'text-white', 'hellix-elementor' ),
				'description' => esc_html__( 'Additional CSS class that you want to apply to the <a> tag', 'hellix-elementor' ),
			]
		);

		$repeater->add_control(
			'icon_link',
			[
				'label'       => esc_html__( 'Link', 'hellix-elementor' ),
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'default'     => [
					'url' => 'https://facebook.com/',
				],
			]
		);

		$this->add_control(
			'hero_icon_list',
			[
				'label'              => esc_html__( 'Icon List', 'hellix-elementor' ),
				'type'               => Controls_Manager::REPEATER,
				'fields'             => $repeater->get_controls(),
				'show_label'         => true,
				'default'            => [
					[
						'selected_item_icon' => '.Facebook',
						'icon_link'          => [
							'url' => 'https://facebook.com/',
						],
					],
					[
						'selected_item_icon' => '.Instagram',
						'icon_link'          => [
							'url' => 'https://instagram.com/',
						],
					],
					[
						'selected_item_icon' => '.Twitter',
						'icon_link'          => [
							'url' => 'https://twitter.com/',
						],
					],
					[
						'selected_item_icon' => '.Behance',
						'icon_link'          => [
							'url' => 'https://behance.com/',
						],
					],
				],
				'selected_item_icon' => '{{{ text }}}',
			]
		);
		$this->end_controls_section();
	}

	 /**
	  * Print Slider
	  *
	  * @param  array $settings The Widget settings.
	  *
	  * @return void
	  */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;
		$count  = 1;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}

		$widget->add_render_attribute(
			'masthead',
			array(
				'class' => 'masthead swiper-container js-slider',
			)
		); ?>

		<section <?php $widget->print_render_attribute_string( 'masthead' ); ?>>
			<div class="swiper-wrapper">
			   <?php foreach ( $settings['slides'] as $slide ) : ?>
					<?php
					$this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'], $count );
					$count++;
					?>
				<?php endforeach; ?>
			</div>

			 <?php
				if ( 'yes' == $settings['show_dots'] ) {
					?>
				<div class="masthead__pagination_numbers pagination_color__title js-pag-numbers lg:d-none">
					<span class="js-current pagination_color__title"></span>
					<span class="pagination_color__title">/</span>
					<span class="js-all"></span>
				</div>
					  <?php $this->render_social_icons(); ?>  
				<div class="masthead-pagination js-pag pagination_color__title">
					<?php $this->render_pagination( $settings ); ?>
				</div>
				  <?php } ?>
			<div class="masthead__scroll js-scroll md:d-none">
				<div class="masthead__scroll_item">
					<?php echo esc_html__( 'Scroll', 'hellix-elementor' ); ?>
					<div class="masthead__scroll_icon">
						<i class="icon icon-right-arrow"></i>
					</div>
				</div>
			</div>
		</section>
		 <?php
	}

	 /**
	  * Render Hero Carousel Pagination
	  *
	  * @param  array $settings The widget settings.
	  * @return void
	  */
	public function render_pagination( $settings ) {
		$widget = $this->parent;
		foreach ( $settings['slides'] as $index => $slide ) :
			$count = $index + 1;
			$widget->add_render_attribute(
				'pagination-' . $count,
				[
					'class'       => [ 'masthead-pagination__item', 'js-pag-item' ],
					'data-cursor' => '',
				]
			);

			if ( 1 === $count ) {
				$widget->add_render_attribute( 'pagination-' . $count, 'class', 'is-active' );
			}

			?>
			<div <?php $this->parent->print_render_attribute_string( 'pagination-' . $count ); ?>>
				<span class="masthead-pagination__number pagination_color__title"><?php echo esc_html( zeroise( $index + 1, 2 ) ); ?></span>
				<h4 class="masthead-pagination__title pagination_color__title md:d-none">
				   <?php echo wp_kses_post( $slide['title'] ); ?><br>
				</h4>
				<span class="masthead-pagination__line"></span>
			</div>
			 <?php
		 endforeach;
	}

	 /**
	  * Render social icons
	  *
	  * @return void
	  */
	public function render_social_icons() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();

		$skin_control_ids = [
			'hero_icon_list',
		];

		$skin_settings = [];

		foreach ( $skin_control_ids as $skin_control_id ) {
			$skin_settings[ $skin_control_id ] = $this->get_instance_value( $skin_control_id );
		}
		?>
		<div class="masthead__socials js-socials md:d-none">
			<div class="masthead__socials_item">
			   <?php
				foreach ( $skin_settings['hero_icon_list'] as $key => $item ) {
					$count = $key + 1;

					$icon_class = 'hx-hero__icon_wrap ' . $item['selected_icon_class'];
					$widget->add_render_attribute( 'icon_link' . $count, 'class', $icon_class );

					if ( ! empty( $item['icon_link']['url'] ) ) {
						$widget->add_link_attributes( 'icon_link' . $count, $item['icon_link'] );
					}
					?>
					<a <?php $widget->print_render_attribute_string( 'icon_link' . $count ); ?>><?php echo esc_html( $item['selected_item_icon'] ); ?></a>
					<?php
				}
				?>
			</div>
		</div>
		 <?php
	}

	 /**
	  * Print the slide.
	  *
	  * @param  array $slide    The slide information.
	  * @param  array $settings The widget settings.
	  * @param  int   $index    The slide number.
	  * @param  int   $count    The loop count.
	  * @return void
	  */
	protected function print_slide( array $slide, array $settings, $index, $count ) {

		$widget    = $this->parent;
		$btn_txt   = $slide['btn_text'];
		$class_btn = 'button__text_color button -' . $settings['button_type'];

		$widget->add_render_attribute( 'button-' . $index, 'class', $class_btn );
		if ( ! empty( $slide['btn_link']['url'] ) ) {
			$widget->add_link_attributes( 'button-' . $index, $slide['btn_link'] );
		}

		?>
		<div class="swiper-slide">
			<div data-parallax="0.6" class="masthead__image" data-swiper-parallax="40%">
			   <?php echo wp_kses_post( $widget->get_slide_image_html( $slide, $index ) ); ?>
			</div>
			<div class="container-fluid h-100 px-32">
				<div class="row align-items-center">
					<div class="col-lg-10 offset-lg-2 offset-md-1">
						<div class="masthead__content js-content">
						   <?php
							if ( 1 === $count ) {
								$widget->add_render_attribute( 'data-attr-' . $index, 'data-anim', 'split-lines' );
							}
							$widget->add_render_attribute( 'data-attr-' . $index, 'data-split', 'lines' );
							$widget->add_render_attribute( 'data-attr-' . $index, 'class', 'js-title-wrap' );
							?>
							<div <?php $widget->print_render_attribute_string( 'data-attr-' . $index ); ?>>
							   <?php $this->render_title( $settings, $slide, $index ); ?>
							</div>
							<div class="masthead__button js-button">
								<a <?php $widget->print_render_attribute_string( 'button-' . $index ); ?>><?php echo esc_html( $btn_txt ); ?>
								</a>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		 <?php
	}

	 /**
	  * Render the title of the slide.
	  *
	  * @param  array $settings The Widget settings.
	  * @param  array $slide    The slide information.
	  * @param  int   $i        Index of the slide.
	  * @return void
	  */
	public function render_title( $settings, $slide, $i ) {
		$widget = $this->parent;
		$widget->add_render_attribute(
			'title_css' . $i,
			'class',
			[
				'hx-hero__title',
				'masthead__title',
				'js-title ' . $settings['title_css'],
			]
		);

		$tag = $settings['title_tag'];
		?>
		<<?php echo esc_attr( $tag ); ?> <?php $widget->print_render_attribute_string( 'title_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['title'] ); ?>
		</<?php echo esc_attr( $tag ); ?>>
		 <?php
	}

	 /**
	  * Render the widget in the frontend.
	  */
	public function render() {
		$widget  = $this->parent;
		$hero_v1 = uniqid( 'hero-v1-' );
		$widget->add_render_attribute( 'masthead', 'id', $hero_v1 );
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script( $hero_v1 );

	}

	 /**
	  * Render script in the editor.
	  *
	  * @param string $hero_v1 passing id.
	  */
	public function render_script( $hero_v1 ) {
		if ( Elementor\Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				
				 /**
				 * Editor Slider Load.
				 */
				var MainSlider = (function() {
					// const slider = document.querySelector('.js-slider');
					let sliderInstance;
					let currentIndex = 0;

					function sliderInit() {
						sliderInstance = new Swiper(document.getElementById( "<?php echo esc_attr( $hero_v1 ); ?>" ), {
						spaceBetween: 0,
						speed: 1000,
						parallax: true,
						lazy: {
							loadPrevNext: true,
						},
						breakpoints: {
							575: {
							parallax: false,
							},
						},
						});
					}

					function numberPagination() {
						const pagination = document.querySelector('#<?php echo esc_attr( $hero_v1 ); ?> .js-pag-numbers');
						const current = pagination.querySelector('.js-current');
						const all = pagination.querySelector('.js-all');

						current.innerHTML = '01';
						all.innerHTML = '0' + sliderInstance.slides.length;

						sliderInstance.on('slideChangeTransitionStart', function () {
						current.innerHTML = `0${sliderInstance.activeIndex + 1}`;
						});
					}

					function pagination() {
						const pagination = document.querySelector('#<?php echo esc_attr( $hero_v1 ); ?> .js-pag');
						const items = pagination.querySelectorAll('.js-pag-item');

						sliderInstance.on('slideChangeTransitionStart', function () {
						pagination.querySelector('.is-active').classList.remove('is-active');
						items[sliderInstance.activeIndex].classList.add('is-active');
						});

						for (let i = 0; i < items.length; i++) {
						const el = items[i];
						
						el.addEventListener('click', (e) => {
							sliderInstance.slideTo(i)
						})
						}
					}

					function sliderEvents() {
						sliderInstance.on('slideChangeTransitionEnd', function () {
						hideContent(sliderInstance.slides[currentIndex]);
						showContent(sliderInstance.slides[sliderInstance.activeIndex]);
						currentIndex = sliderInstance.activeIndex;
						});
					}

					function hideContent(slide) {
						const lines = slide.querySelectorAll('.js-title .split__line')
						const button = slide.querySelector('.js-button')

						gsap.timeline()
						.set(lines, {
							y: '100%',
						})
						.set(button, {
							opacity: 0,
						});
					}

					function showContent(slide) {
						const lines = slide.querySelectorAll('.js-title .split__line')
						const button = slide.querySelector('.js-button')

						gsap.timeline()
						.to(lines, {
							stagger: 0.1,
							duration: 0.9,
							ease: 'power3.out',
							y: '0%',
						})
						.to(button, {
							opacity: 1,
							duration: 0.6,
							ease: 'power3.out',
						}, ">-0.3");
					}

					function init() {
						if (!document.querySelector('#<?php echo esc_attr( $hero_v1 ); ?>')) return;
						sliderInit();
						sliderEvents();
						pagination();
						numberPagination();
					}

					return {
						init: init,
					}
					})();
					MainSlider.init();
			</script>
			 <?php
		 endif;
	}

}
