<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as AR_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Hero Style 2.
 */
class Hero_Style_10 extends Skin_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hero-caorusel-10';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hero Carousel 10', 'hellix-elementor' );
	}

	/**
	 * Print Slider
	 *
	 * @param  array $settings The Widget settings.
	 *
	 * @return void
	 */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}

		$widget->add_render_attribute(
			'mainSlider',
			array(
				'data-anim-wrap' => '',
				'class'          => 'mainSlider -type-10 swiper-container js-mainSlider-type-all',
			)
		); ?>

		<section <?php $widget->print_render_attribute_string( 'mainSlider' ); ?>>

			<div class="swiper-wrapper">
				<?php foreach ( $settings['slides'] as $slide ) : ?>

					<?php $this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'] ); ?>

				<?php endforeach; ?>
			</div>
			<?php
			if ( 'yes' == $settings['show_dots'] ) {
				?>
				<div class="pagination -slider -white js-pagination"></div>
			<?php } ?>
		</section>
		<?php
	}

	/**
	 * Print the slide.
	 *
	 * @param  array $slide    The slide information.
	 * @param  array $settings The widget settings.
	 * @param  int   $index    The slide number.
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $index ) {

		$widget    = $this->parent;
		$btn_txt   = $slide['btn_text'];
		$class_btn = 'button__text_color button -md -' . $settings['button_type'];

		$widget->add_render_attribute( 'button-' . $index, 'class', $class_btn );
		if ( ! empty( $slide['btn_link']['url'] ) ) {
			$widget->add_link_attributes( 'button-' . $index, $slide['btn_link'] );
		}
		?>
		<div class="swiper-slide">
			
			<?php if ( ! empty( $slide['image']['url'] ) ) { ?>
			<div data-parallax="0.6" class="mainSlider__image" data-swiper-parallax="50%">
				<?php echo wp_kses_post( $widget->get_slide_image_html( $slide, $index ) ); ?>
			</div>
			<?php } ?>

			<div class="container">
				<div class="row justify-content-center align-items-center">
					<div class="mainSlider__content js-content">
						<div class="col-xl-8 col-lg-9 col-md-11">

							<?php if ( ! empty( $slide['pre_title'] ) ) { ?>
							<div class="mainSlider__subtitle text-white js-all-item">
								<?php echo esc_html( $slide['pre_title'] ); ?>
							</div>
							<?php } ?>

							<?php if ( ! empty( $slide['title'] ) ) { ?>
								<?php $this->render_title( $settings, $slide, $index ); ?>
							<?php } ?>

						</div>
						<div class="col-xl-6 col-lg-7 col-md-10">
							<?php if ( ! empty( $slide['description'] ) ) { ?>
							<div class="mainSlider__text text-white mt-8 js-all-item">
								<?php $this->render_desc( $settings, $slide, $index ); ?>
							</div>
							<?php } ?>
							<?php if ( ! empty( $slide['btn_text'] ) ) { ?>
							<div class="mainSlider__button mt-20 js-all-item">
								<a <?php $widget->print_render_attribute_string( 'button-' . $index ); ?>><?php echo esc_html( $btn_txt ); ?>
								</a>
							</div>
						<?php } ?>
						</div>
					</div>      
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render the title of the slide.
	 *
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @param  int   $i        Index of the slide.
	 * @return void
	 */
	public function render_title( $settings, $slide, $i ) {

		$widget = $this->parent;
		$widget->add_render_attribute(
			'title_css' . $i,
			'class',
			[
				'hx-hero__title',
				'mainSlider__title',
				'mt-8',
				'js-all-item',
				'text-white ',
				$settings['title_css'],
			]
		);

		$tag = $settings['title_tag'];

		?>
		<<?php echo esc_attr( $tag ); ?> <?php $widget->print_render_attribute_string( 'title_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['title'] ); ?>
		</<?php echo esc_attr( $tag ); ?>> 
		<?php
	}

	/**
	 * Render the Description of the slide.
	 *
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @param  int   $i        Index of the slide.
	 * @return void
	 */
	public function render_desc( $settings, $slide, $i ) {

		$widget = $this->parent;
		$widget->add_render_attribute(
			'desc_css' . $i,
			'class',
			[
				'hx-hero__desc_title ',
				$settings['desc_css'],
			]
		);

		?>
		<p <?php $widget->print_render_attribute_string( 'desc_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['description'] ); ?>
		</p>
		<?php
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$widget   = $this->parent;
		$hero_v10 = uniqid( 'hero-v10-' );
		$widget->add_render_attribute( 'mainSlider', 'id', $hero_v10 );
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script( $hero_v10 );
	}

	/**
	 * Render script in the editor.
	 *
	 * @param string $hero_v10 passing id.
	 */
	public function render_script( $hero_v10 ) {
		if ( Elementor\Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				
				 /**
				 * Editor Slider Load.
				 */
				var MainSliderAll = (function() {
					let sliderInstance;
					let currentIndex = 0;

					function sliderInit() {
						sliderInstance = new Swiper(document.getElementById( "<?php echo esc_attr( $hero_v10 ); ?>" ), {
						spaceBetween: 0,
						speed: 1000,
						parallax: true,
						// direction: 'vertical',
						lazy: {
							loadPrevNext: true,
						},
						breakpoints: {
							575: {
							parallax: false,
							},
						},
						navigation: {
							prevEl: document.querySelector('#<?php echo esc_attr( $hero_v10 ); ?> .js-nav-prev'),
							nextEl: document.querySelector('#<?php echo esc_attr( $hero_v10 ); ?> .js-nav-next'),
						},
						pagination: {
							el: document.querySelector('#<?php echo esc_attr( $hero_v10 ); ?> .js-pagination'),
							bulletClass: 'pagination__item',
							bulletActiveClass: 'is-active',
							bulletElement: 'div',
							clickable: true
						},
						});
					}

					function sliderEvents() {
						sliderInstance.on('slideChangeTransitionEnd', function () {
						hideContent(sliderInstance.slides[currentIndex]);
						showContent(sliderInstance.slides[sliderInstance.activeIndex]);
						currentIndex = sliderInstance.activeIndex;
						});
					}

					function hideContent(slide) {
						const lines = slide.querySelectorAll('.js-title .split__line')
						const text = slide.querySelector('.js-text')
						const button = slide.querySelector('.js-button')

						gsap.timeline()
						.set(lines, {
							y: '100%',
						})
						.set(text, {
							opacity: 0,
							y: '30px',
						})
						.set(button, {
							opacity: 0,
							y: '30px',
						});
					}

					function showContent(slide) {
						const lines = slide.querySelectorAll('.js-title .split__line')
						const text = slide.querySelector('.js-text')
						const button = slide.querySelector('.js-button')

						gsap.timeline()
						.to(lines, {
							stagger: 0.1,
							duration: 0.9,
							ease: 'power3.out',
							y: '0%',
						})
						.to(text, {
							duration: 0.6,
							ease: 'power3.out',
							opacity: 1,
							y: '0%',
						}, ">-0.4")
						.to(button, {
							duration: 0.6,
							ease: 'power3.out',
							opacity: 1,
							y: '0%',
						}, ">-0.4");
					}

					function hideSlides() {
						const lines = document.querySelectorAll('#<?php echo esc_attr( $hero_v10 ); ?> .js-title .split__line')
						const text = document.querySelectorAll('#<?php echo esc_attr( $hero_v10 ); ?> .js-text')
						const button = document.querySelectorAll('#<?php echo esc_attr( $hero_v10 ); ?> .js-button')

						gsap.timeline()
						.set(lines, {
							y: '100%',
						})
						.set(text, {
							opacity: 0,
							y: '30px',
						})
						.set(button, {
							opacity: 0,
							y: '30px',
						});
					}

					function init() {
						if (!document.querySelector('#<?php echo esc_attr( $hero_v10 ); ?>')) return;
						sliderInit();
						hideSlides();
						sliderEvents();
					}

					return {
						init: init,
					}
				})();
				function container() {
						var animationContainer = document.querySelectorAll('[data-anim-wrap]');

						if (!animationContainer.length) {
							return;
						}
						
						for (let i = 0; i < animationContainer.length; i++) {
							const el = animationContainer[i];
						
							new ScrollMagic.Scene({
							offset: '160px',
							triggerElement: el,
							triggerHook: "onEnter",
							reverse: false,
							})
							.on('enter', function (event) {
							
							const animChilds = el.querySelectorAll('[data-anim-child]');
							el.classList.add('animated');
							animChilds.forEach(el => animateElement(el));
							
							})
							.addTo(App.SMcontroller)
						}

						}	
						MainSliderAll.init();
						container();								
			</script>
			<?php
		endif;
	}

}
