<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as AR_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Hero Style 2.
 */
class Hero_Style_2 extends Skin_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hero-caorusel-2';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hero Carousel 2', 'hellix-elementor' );
	}

	/**
	 * Print Slider
	 *
	 * @param  array $settings The Widget settings.
	 *
	 * @return void
	 */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;
		$count  = 1;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}

		$widget->add_render_attribute(
			'slider',
			array(
				'class' => 'mainSlider -type-2 swiper-container js-mainSlider-type-2',
			)
		); ?>

		<section <?php $widget->print_render_attribute_string( 'slider' ); ?>>
			
			<div class="swiper-wrapper">
				<?php foreach ( $settings['slides'] as $slide ) : ?>

					<?php
					$this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'], $count );
					$count ++;
					?>
 
				<?php endforeach; ?>
			</div>
			<?php if ( 'yes' == $settings['show_arrows'] ) { ?>
				<?php $this->render_btn_action(); ?>
			<?php } ?>
			<?php
			if ( 'yes' == $settings['show_dots'] ) {
				?>
				<div class="mainSlider-pagination js-pagination"></div>
			<?php } ?>
			
		</section>
		<?php
	}

	/**
	 * Print the slide.
	 *
	 * @param  array $slide    The slide information.
	 * @param  array $settings The widget settings.
	 * @param  int   $index    The slide number.
	 * @param  int   $count    The loop count.
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $index, $count ) {

		$widget    = $this->parent;
		$btn_txt   = $slide['btn_text'];
		$class_btn = 'button__text_color button -md -' . $settings['button_type'];

		$widget->add_render_attribute( 'button-' . $index, 'class', $class_btn );
		if ( ! empty( $slide['btn_link']['url'] ) ) {
			$widget->add_link_attributes( 'button-' . $index, $slide['btn_link'] );
		}

		?>
		<div class="swiper-slide">
			<div data-parallax="0.6" class="mainSlider__image" data-swiper-parallax="40%">
				<?php echo wp_kses_post( $widget->get_slide_image_html( $slide, $index ) ); ?>
			</div>

			<div class="container">
				<div class="row justify-content-center align-items-center">
					<div class="col-xl-10 col-md-11">
						<div class="mainSlider__content text-center js-content">
							<?php
							if ( 1 === $count ) {
								$widget->add_render_attribute( 'data-attr-' . $index, 'data-anim', 'split-lines' );
							}
							$widget->add_render_attribute( 'data-attr-' . $index, 'data-split', 'lines' );
							$widget->add_render_attribute( 'data-attr-' . $index, 'class', 'js-title-wrap' );
							?>
							<div <?php $widget->print_render_attribute_string( 'data-attr-' . $index ); ?>>
								<?php $this->render_title( $settings, $slide, $index ); ?>
							   
							</div>
							<div class="mainSlider__text text-sm uppercase text-white mt-16 js-text">
								<?php $this->render_desc( $settings, $slide, $index ); ?>
							</div>
							<div class="mainSlider__button mt-32 js-button">
								<a <?php $widget->print_render_attribute_string( 'button-' . $index ); ?>><?php echo esc_html( $btn_txt ); ?>
								</a>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render the Button Action.
	 */
	public function render_btn_action() {

		$widget = $this->parent;

		$widget->add_render_attribute(
			'controls',
			array(
				'class' => 'mainSlider-nav js-nav',
			)
		);

		$widget->add_render_attribute(
			'prev',
			array(
				'class' => '-prev js-nav-prev pagination_color__title',
			)
		);

		$widget->add_render_attribute(
			'next',
			array(
				'class' => '-next js-nav-next pagination_color__title',
			)
		);
		?>

		<div <?php $widget->print_render_attribute_string( 'controls' ); ?>>
			<div <?php $widget->print_render_attribute_string( 'prev' ); ?>>
				<?php echo esc_html__( 'PREV', 'hellix-elementor' ); ?>
			</div>
			<div <?php $widget->print_render_attribute_string( 'next' ); ?>>    <?php echo esc_html__( 'NEXT', 'hellix-elementor' ); ?>         
			</div>
		</div>
		<?php

	}

	/**
	 * Render the title of the slide.
	 *
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @param  int   $i        Index of the slide.
	 * @return void
	 */
	public function render_title( $settings, $slide, $i ) {

		$widget = $this->parent;
		$widget->add_render_attribute(
			'title_css' . $i,
			'class',
			[
				'hx-hero__title',
				'mainSlider__title',
				'js-title',
				'text-white ',
				$settings['title_css'],
			]
		);

		$tag = $settings['title_tag'];

		?>
		<<?php echo esc_attr( $tag ); ?> <?php $widget->print_render_attribute_string( 'title_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['title'] ); ?>
		</<?php echo esc_attr( $tag ); ?>>
		<?php
	}

	/**
	 * Render the Description of the slide.
	 *
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @param  int   $i        Index of the slide.
	 * @return void
	 */
	public function render_desc( $settings, $slide, $i ) {

		$widget = $this->parent;
		$widget->add_render_attribute(
			'desc_css' . $i,
			'class',
			[
				'hx-hero__desc_title ',
				$settings['desc_css'],
			]
		);

		?>
		<p <?php $widget->print_render_attribute_string( 'desc_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['description'] ); ?>
		</p>
		<?php
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$widget  = $this->parent;
		$hero_v2 = uniqid( 'hero-v2-' );
		$widget->add_render_attribute( 'slider', 'id', $hero_v2 );
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script( $hero_v2 );
	}

	/**
	 * Render script in the editor.
	 *
	 * @param string $hero_v2 passing id.
	 */
	public function render_script( $hero_v2 ) {
		if ( Elementor\Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				 /**
				 * Editor Slider Load.
				 */
				var MainSlider2 = (function() {
						let sliderInstance;
						let currentIndex = 0;

						function sliderInit() {
							const slider = document.querySelector('#<?php echo esc_attr( $hero_v2 ); ?>');
							if (!slider) return;

							sliderInstance = new Swiper(slider, {
							spaceBetween: 0,
							speed: 1000,
							parallax: true,
							lazy: {
								loadPrevNext: true,
							},
							breakpoints: {
								575: {
								parallax: false,
								},
							},
							navigation: {
								prevEl: slider.querySelector('.js-nav-prev'),
								nextEl: slider.querySelector('.js-nav-next'),
							},
							pagination: {
								el: slider.querySelector('.js-pagination'),
								bulletClass: 'pagination__item',
								bulletActiveClass: 'is-active',
								bulletElement: 'div',
								clickable: true
							},
							});

							const pagination = slider.querySelectorAll('.js-pagination > div')

							for (let i = 1; i < pagination.length + 1; i++) {
							pagination[i - 1].innerHTML = '0' + i;
							}
						}

						function sliderEvents() {
							sliderInstance.on('slideChangeTransitionEnd', function () {
							hideContent(sliderInstance.slides[currentIndex]);
							showContent(sliderInstance.slides[sliderInstance.activeIndex]);
							currentIndex = sliderInstance.activeIndex;
							});
						}

						function hideContent(slide) {
							const lines = slide.querySelectorAll('.js-title .split__line')
							const text = slide.querySelector('.js-text')
							const button = slide.querySelector('.js-button')

							gsap.timeline()
							.set(lines, {
								y: '100%',
							})
							.set(text, {
								opacity: 0,
								y: '30px',
							})
							.set(button, {
								opacity: 0,
								y: '30px',
							});
						}

						function showContent(slide) {
							const lines = slide.querySelectorAll('.js-title .split__line')
							const text = slide.querySelector('.js-text')
							const button = slide.querySelector('.js-button')

							gsap.timeline()
							.to(lines, {
								stagger: 0.1,
								duration: 0.9,
								ease: 'power3.out',
								y: '0%',
							})
							.to(text, {
								duration: 0.6,
								ease: 'power3.out',
								opacity: 1,
								y: '0%',
							}, ">-0.4")
							.to(button, {
								duration: 0.6,
								ease: 'power3.out',
								opacity: 1,
								y: '0%',
							}, ">-0.4");
						}

						function hideSlides() {
							const slider = document.querySelector('#<?php echo esc_attr( $hero_v2 ); ?>');
							if (!slider) return;
							const lines = slider.querySelectorAll('.js-title .split__line')
							const text = slider.querySelectorAll('.js-text')
							const button = slider.querySelectorAll('.js-button')

							gsap.timeline()
							.set(lines, {
								y: '100%',
							})
							.set(text, {
								opacity: 0,
								y: '30px',
							})
							.set(button, {
								opacity: 0,
								y: '30px',
							});
						}

						function init() {
							const slider = document.querySelector('#<?php echo esc_attr( $hero_v2 ); ?>');
							if (!slider) return;
							sliderInit();
							hideSlides();
							sliderEvents();
						}

						return {
							init: init,
						}
						})();
					MainSlider2.init();
			</script>
			<?php
		endif;
	}

}
