<?php
namespace HellixElementor\Modules\Countdown\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use HellixElementor\Base\Base_Widget;
use Elementor\Plugin;
use HellixElementor\Plugin as HXPlugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * CountDown Widget.
 */
class Countdown extends Base_Widget {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-countdown';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Countdown', 'hellix-elementor' );
	}

	/**
	 * Get the icon for the widget.
	 *
	 * @return string
	 */
	public function get_icon() {
		return 'eicon-countdown';
	}

	/**
	 * Get the keywords associated with the widget.
	 *
	 * @return array
	 */
	public function get_keywords() {
		return [ 'countdown', 'number', 'timer', 'time', 'date', 'evergreen' ];
	}

	/**
	 * Register controls for this widget.
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_countdown',
			[
				'label' => esc_html__( 'Countdown', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'countdown_type',
			[
				'label'     => esc_html__( 'Type', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'due_date' => esc_html__( 'Due Date', 'hellix-elementor' ),
					// 'evergreen' => esc_html__( 'Evergreen Timer', 'hellix-elementor' ),
				],
				'default'   => 'due_date',
				'condition' => [
					'countdown_type' => 'evergreen',
				],
			]
		);

		$this->add_control(
			'due_date',
			[
				'label'       => esc_html__( 'Due Date', 'hellix-elementor' ),
				'type'        => Controls_Manager::DATE_TIME,
				'default'     => gmdate( 'Y-m-d H:i', strtotime( '+1 month' ) + ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS ) ),
				/* translators: %s: Time zone. */
				'description' => sprintf( esc_html__( 'Date set according to your timezone: %s.', 'hellix-elementor' ), Utils::get_timezone_string() ),
				'condition'   => [
					'countdown_type' => 'due_date',
				],
			]
		);

		$this->add_control(
			'evergreen_counter_hours',
			[
				'label'       => esc_html__( 'Hours', 'hellix-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 47,
				'placeholder' => esc_html__( 'Hours', 'hellix-elementor' ),
				'condition'   => [
					'countdown_type' => 'evergreen',
				],
			]
		);

		$this->add_control(
			'evergreen_counter_minutes',
			[
				'label'       => esc_html__( 'Minutes', 'hellix-elementor' ),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 59,
				'placeholder' => esc_html__( 'Minutes', 'hellix-elementor' ),
				'condition'   => [
					'countdown_type' => 'evergreen',
				],
			]
		);

		$this->add_control(
			'show_days',
			[
				'label'     => esc_html__( 'Days', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'default'   => 'yes',
			]
		);

		$this->add_control(
			'show_hours',
			[
				'label'     => esc_html__( 'Hours', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'default'   => 'yes',
			]
		);

		$this->add_control(
			'show_minutes',
			[
				'label'     => esc_html__( 'Minutes', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'default'   => 'yes',
			]
		);

		$this->add_control(
			'show_seconds',
			[
				'label'     => esc_html__( 'Seconds', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'default'   => 'yes',
			]
		);

		$this->add_control(
			'show_labels',
			[
				'label'     => esc_html__( 'Show Label', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'default'   => 'yes',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'custom_labels',
			[
				'label'     => esc_html__( 'Custom Label', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'condition' => [
					'show_labels!' => '',
				],
			]
		);

		$this->add_control(
			'label_days',
			[
				'label'       => esc_html__( 'Days', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Days', 'hellix-elementor' ),
				'placeholder' => esc_html__( 'Days', 'hellix-elementor' ),
				'condition'   => [
					'show_labels!'   => '',
					'custom_labels!' => '',
					'show_days'      => 'yes',
				],
			]
		);

		$this->add_control(
			'label_hours',
			[
				'label'       => esc_html__( 'Hours', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Hours', 'hellix-elementor' ),
				'placeholder' => esc_html__( 'Hours', 'hellix-elementor' ),
				'condition'   => [
					'show_labels!'   => '',
					'custom_labels!' => '',
					'show_hours'     => 'yes',
				],
			]
		);

		$this->add_control(
			'label_minutes',
			[
				'label'       => esc_html__( 'Minutes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Minutes', 'hellix-elementor' ),
				'placeholder' => esc_html__( 'Minutes', 'hellix-elementor' ),
				'condition'   => [
					'show_labels!'   => '',
					'custom_labels!' => '',
					'show_minutes'   => 'yes',
				],
			]
		);

		$this->add_control(
			'label_seconds',
			[
				'label'       => esc_html__( 'Seconds', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Seconds', 'hellix-elementor' ),
				'placeholder' => esc_html__( 'Seconds', 'hellix-elementor' ),
				'condition'   => [
					'show_labels!'   => '',
					'custom_labels!' => '',
					'show_seconds'   => 'yes',
				],
			]
		);

		$this->add_control(
			'expire_actions',
			[
				'label'       => __( 'Actions After Expire', 'hellix-elementor' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'none'     => __( 'None', 'hellix-elementor' ),
					'redirect' => __( 'Redirect', 'hellix-elementor' ),
					'hide'     => __( 'Hide', 'hellix-elementor' ),
					'message'  => __( 'Show Message', 'hellix-elementor' ),
				],
				'default'     => 'none',
				'label_block' => true,
				'separator'   => 'before',
				'render_type' => 'none',
				'multiple'    => true,
			]
		);

		$this->add_control(
			'message_after_expire',
			[
				'label'     => __( 'Message', 'hellix-elementor' ),
				'type'      => Controls_Manager::TEXTAREA,
				'separator' => 'before',
				'dynamic'   => [
					'active' => true,
				],
				'condition' => [
					'expire_actions' => 'message',
				],
			]
		);

		$this->add_control(
			'expire_redirect_url',
			[
				'label'     => __( 'Redirect URL', 'hellix-elementor' ),
				'type'      => Controls_Manager::URL,
				'separator' => 'before',
				'options'   => false,
				'dynamic'   => [
					'active' => true,
				],
				'condition' => [
					'expire_actions' => 'redirect',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'heading_item',
			[
				'label' => esc_html__( 'Item', 'hellix-elementor' ),
				'type'  => Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'days_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Classses added to .countdown-days', 'hellix-elementor' ),
				'condition'   => [ 'show_days' => 'yes' ],
				'dynamic'     => [ 'active' => true ],
			]
		);

		$this->add_control(
			'hours_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Classses added to .countdown-hours', 'hellix-elementor' ),
				'condition'   => [ 'show_hours' => 'yes' ],
				'dynamic'     => [ 'active' => true ],
			]
		);

		$this->add_control(
			'minutes_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Classses added to .countdown-minutes', 'hellix-elementor' ),
				'condition'   => [ 'show_minutes' => 'yes' ],
				'dynamic'     => [ 'active' => true ],
			]
		);

		$this->add_control(
			'seconds_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Classses added to .countdown-seconds', 'hellix-elementor' ),
				'condition'   => [ 'show_seconds' => 'yes' ],
				'dynamic'     => [ 'active' => true ],
			]
		);

		$this->add_control(
			'heading_digits',
			[
				'label'     => esc_html__( 'Digits', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'digits_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .countdown-value' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'digits_typography',
				'selector' => '{{WRAPPER}} .countdown-value',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'digits_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Classses added to .countdown-value', 'hellix-elementor' ),
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'heading_label',
			[
				'label'     => esc_html__( 'Label', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'label_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .countdown-label' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'label_typography',
				'selector' => '{{WRAPPER}} .countdown-label',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
			]
		);

		$this->add_control(
			'label_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Classses added to .countdown-label', 'hellix-elementor' ),
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Get Strftime.
	 *
	 * @param  array $instance The instance information.
	 */
	private function get_strftime( array $instance ) {
		$string = '';

		$this->add_render_attribute( 'countdown-item', 'class', 'countdown-item' );
		if ( ! empty( $instance['item_css'] ) ) {
			$this->add_render_attribute( 'countdown-item', 'class', $instance['item_css'] );
		}

		$this->add_render_attribute( 'countdown-value', 'class', 'countdown-value' );
		if ( ! empty( $instance['digits_css'] ) ) {
			$this->add_render_attribute( 'countdown-value', 'class', $instance['digits_css'] );
		}

		$this->add_render_attribute( 'countdown-label', 'class', 'countdown-label' );
		if ( ! empty( $instance['label_css'] ) ) {
			$this->add_render_attribute( 'countdown-label', 'class', $instance['label_css'] );
		}

		if ( ! empty( $instance['border_class'] ) ) {
			$this->add_render_attribute( 'countdown-border', 'class', $instance['border_class'] );
		}

		if ( $instance['show_days'] ) {

			$part_class =
				[
					'time'  => 'days',
					'class' => '',
				];
			if ( ! empty( $instance['days_css'] ) ) {
				$part_class['class'] = $instance['days_css'];
			}
			$string .= $this->render_countdown_item( $instance, 'label_days', $part_class );
		}
		if ( $instance['show_hours'] ) {

			$part_class =
				[
					'time'  => 'hours',
					'class' => '',
				];
			if ( ! empty( $instance['hours_css'] ) ) {
				$part_class['class'] = ' ' . $instance['hours_css'];
			}
			$string .= $this->render_countdown_item( $instance, 'label_hours', $part_class );
		}
		if ( $instance['show_minutes'] ) {
			$part_class =
				[
					'time'  => 'minutes',
					'class' => '',
				];
			if ( ! empty( $instance['minutes_css'] ) ) {
				$part_class['class'] = ' ' . $instance['minutes_css'];
			}
			$string .= $this->render_countdown_item( $instance, 'label_minutes', $part_class );
		}
		if ( $instance['show_seconds'] ) {
			$part_class =
				[
					'time'  => 'seconds',
					'class' => '',
				];
			if ( ! empty( $instance['seconds_css'] ) ) {
				$part_class['class'] = ' ' . $instance['seconds_css'];
			}
			$string .= $this->render_countdown_item( $instance, 'label_seconds', $part_class );
		}

		return $string;
	}

	/**
	 * $_default_countdown_labels.
	 *
	 * @var mixed
	 */
	private $_default_countdown_labels;

	/**
	 * Init Default Countdown Labels .
	 */
	private function init_default_countdown_labels() {
		$this->_default_countdown_labels = [
			'label_months'  => esc_html__( 'Months', 'hellix-elementor' ),
			'label_weeks'   => esc_html__( 'Weeks', 'hellix-elementor' ),
			'label_days'    => esc_html__( 'Days', 'hellix-elementor' ),
			'label_hours'   => esc_html__( 'Hours', 'hellix-elementor' ),
			'label_minutes' => esc_html__( 'Minutes', 'hellix-elementor' ),
			'label_seconds' => esc_html__( 'Seconds', 'hellix-elementor' ),
		];
	}

	/**
	 * Get The Default Countdown Labels.
	 */
	public function get_default_countdown_labels() {

		if ( ! $this->_default_countdown_labels ) {
			$this->init_default_countdown_labels();
		}

		return $this->_default_countdown_labels;
	}

	/**
	 * Render the countdown items.
	 *
	 * @param  array $instance      The instance information.
	 * @param  mixed $label         The label.
	 * @param  mixed $part_class    The Part Class.
	 */
	private function render_countdown_item( $instance, $label, $part_class ) {

			$digits_css = $instance['digits_css'];
			$label_css  = $instance['label_css'];
			$string     = '<div class="col-lg-2 col-6"><div class="soon__count_item">';
			$string    .= '<div class="countdown-value ' . esc_attr( $digits_css ) . esc_attr( $part_class['class'] ) . ' elementor-countdown-' . esc_attr( $part_class['time'] ) . ' js-soon-' . esc_attr( $part_class['time'] ) . '">0</div>';

		if ( $instance['show_labels'] ) {
			$default_labels = $this->get_default_countdown_labels();
			$label          = ( $instance['custom_labels'] ) ? $instance[ $label ] : $default_labels[ $label ];
			$string        .= '<div class="countdown-label ' . esc_attr( $label_css ) . '">' . esc_html( $label ) . '</div>';
		}

		$string .= '</div>';

		$string .= '</div>';

		return $string;
	}

	/**
	 * Get Evergreen Interval.
	 *
	 * @param  array $instance The instance information.
	 */
	private function get_evergreen_interval( $instance ) {
		$hours              = empty( $instance['evergreen_counter_hours'] ) ? 0 : ( $instance['evergreen_counter_hours'] * HOUR_IN_SECONDS );
		$minutes            = empty( $instance['evergreen_counter_minutes'] ) ? 0 : ( $instance['evergreen_counter_minutes'] * MINUTE_IN_SECONDS );
		$evergreen_interval = $hours + $minutes;

		return $evergreen_interval;
	}

	/**
	 * Get Actions.
	 *
	 * @param  array $settings The Widget settings.
	 */
	private function get_actions( $settings ) {
		if ( empty( $settings['expire_actions'] ) || ! is_array( $settings['expire_actions'] ) ) {
			return false;
		}

		$actions = [];

		foreach ( $settings['expire_actions'] as $action ) {
			$action_to_run = [ 'type' => $action ];
			if ( 'redirect' === $action ) {
				if ( empty( $settings['expire_redirect_url']['url'] ) ) {
					continue;
				}
				$action_to_run['redirect_url'] = $settings['expire_redirect_url']['url'];
			}
			$actions[] = $action_to_run;
		}

		return $actions;
	}

	/**
	 * Render the widget in the frontend.
	 */
	protected function render() {
		$instance = $this->get_settings_for_display();
		$due_date = $instance['due_date'];
		$string   = $this->get_strftime( $instance );

		// Handle timezone ( we need to set GMT time ).
		$gmt      = get_gmt_from_date( $due_date . ':00' );
		$due_date = strtotime( $gmt );
		$dated    = gmdate( 'd M Y H:i:s', $due_date );
		$link     = isset( $instance['expire_redirect_url']['url'] ) ? $instance['expire_redirect_url']['url'] : '';

		$actions = false;

		if ( ! HXPlugin::elementor()->editor->is_edit_mode() ) {
			$actions = $this->get_actions( $instance );
		}

		if ( $actions ) {
			$this->add_render_attribute( 'div', 'data-expire-actions', json_encode( $actions ) );
		}

		$this->add_render_attribute(
			'div',
			[
				'id'             => 'countdown-' . uniqid(),
				'class'          => 'soon__count mt-64',
				'data-countdown' => $dated,
			]
		);

		if ( ! empty( $instance['countdown_css'] ) ) {
			$this->add_render_attribute( 'div', 'class', $instance['countdown_css'] );
		}
		$this->add_render_attribute(
			'expire-action',
			[
				'id'    => 'new-message',
				'class' => $instance['expire_actions'],
				'href'  => $link,
			]
		);

		?>
		<div <?php $this->print_render_attribute_string( 'div' ); ?>>
			<div id ="demo" class="row x-gap-48 y-gap-48 justify-content-between js-soon-timer ">
			<?php echo wp_kses_post( $string ); ?>
			</div>
			<div class="d-none">
			<a <?php $this->print_render_attribute_string( 'expire-action' ); ?>>
				<?php echo wp_kses_post( '<div class="elementor-countdown-expire--message">' . $instance['message_after_expire'] . '</div>' ); ?>
			</a>
			</div>
		</div>
		<?php
		$this->render_script();
	}

	/**
	 * Render script in the editor.
	 */
	public function render_script() {
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				/**
				 * Editor Slider Load.
				 */
				function comingSoon() {
					const target = document.querySelector('.js-soon-timer');
					if (!target) return;
					var elId = document.querySelector('.soon__count').id
					var el = document.getElementById(elId);
					var dated = el.getAttribute('data-countdown');
					var countDownDate = new Date( dated ).getTime();

					var x = setInterval(function() {
					var now = new Date().getTime();

					var distance = countDownDate - now;
					if (distance < 0) {
						var days = 0;
						var hours = 0;
						var minutes = 0;
						var seconds = 0;
					} else {
					var days = Math.floor(distance / (1000 * 60 * 60 * 24));
					var hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
					var minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
					var seconds = Math.floor((distance % (1000 * 60)) / 1000);
					}

					document.querySelector('.js-soon-days').innerHTML = days;
					document.querySelector('.js-soon-hours').innerHTML = hours;
					document.querySelector('.js-soon-minutes').innerHTML = minutes;
					document.querySelector('.js-soon-seconds').innerHTML = seconds;

					if (distance < 0) {
						clearInterval(x);
						var html  = document.getElementById("new-message").innerHTML;
						var htmla = document.getElementById("new-message");
						var message = htmla.getAttribute('class');
						var link  = htmla.getAttribute('href');
						if ( message == 'hide' ) {
							document.getElementById("demo").innerHTML = '';
						}
						if ( message == 'message' ) {
							document.getElementById("demo").innerHTML = html;
						}	
					}
					}, 1000);
				}
				comingSoon();
			</script>
			<?php
		endif;
	}

}
