<?php

namespace HellixElementor\Modules\IconBox;

use HellixElementor\Base\Module_Base;
use HellixElementor\Modules\IconBox\Skins;
use Elementor\Controls_Manager;
use Elementor\Icons_Manager;
use Elementor\Utils;
use HellixElementor\Plugin;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module for Icon Box
 */
class Module extends Module_Base {

	/**
	 * Constructor.
	 *
	 * @return void
	 */
	public function __construct() {
		parent::__construct();

		$this->add_actions();
	}

	/**
	 * Add Actions.
	 *
	 * @return void
	 */
	public function add_actions() {
		add_action( 'elementor/widget/icon-box/skins_init', [ $this, 'init_skins' ], 10 );
		add_action( 'elementor/element/icon-box/section_style_icon/before_section_end', [ $this, 'register_style_icon_controls' ] );
		add_action( 'elementor/element/icon-box/section_style_content/before_section_end', [ $this, 'register_style_content_controls' ], 10 );
	}

	/**
	 * Register Style Icon controls.
	 *
	 * @param \Elementor\Widget_Base $widget The Icon Box Widget.
	 *
	 * @return void
	 */
	public function register_style_icon_controls( $widget ) {
		$update_control_ids = [ 'primary_color', 'icon_space', 'rotate' ];

		foreach ( $update_control_ids as $update_control_id ) {
			$widget->update_control(
				$update_control_id,
				[
					'condition' => [
						'_skin!' => [ 'card-hellix', 'hellix-style-2', 'hellix-style-3' ],
					],
				]
			);
		}

		$widget->update_control(
			'icon_size',
			[
				'selectors' => [
					'{{WRAPPER}} .elementor-icon' => 'font-size: {{SIZE}}{{UNIT}} !important;',
				],
					
			]
		);

		$widget->add_control(
			'icon_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#D7926B',
				'selectors' => [
					'{{WRAPPER}} .elementor-icon-box' => 'fill: {{VALUE}}; color: {{VALUE}}!important;',
				],
			]
		);

		$widget->add_control(
			'icon_css',
			[
				'label'       => esc_html__( 'Icon CSS', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Applied to icon wrapper', 'hellix-elementor' ),
				'classes'     => 'elementor-control-direction-ltr',

			]
		);

		$widget->add_control(
			'icon_wraper_css',
			[
				'label'       => esc_html__( 'Icon Wrapper CSS', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Applied to icon wrapper', 'hellix-elementor' ),
				'classes'     => 'elementor-control-direction-ltr',
			]
		);

		$widget->add_control(
			'rounded_size',
			[
				'label'     => esc_html__( 'Rounded Size', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => '2xl',
				'options'   => [
					'2xl' => esc_html__( '2xl', 'hellix-elementor' ),
					'3xl' => esc_html__( '3xl', 'hellix-elementor' ),
				],
				'condition' => [ '_skin!' => 'hellix-style-1' ],
			]
		);

	}

	/**
	 * Register Style Content controls.
	 *
	 * @param \Elementor\Widget_Base $widget The Icon Box Widget.
	 *
	 * @return void
	 */
	public function register_style_content_controls( $widget ) {

		$update_control_ids = [ 'content_vertical_alignment', 'text_align', 'icon_colors_normal', 'icon_colors_hover', 'heading_title' ];

		foreach ( $update_control_ids as $update_control_id ) {
			$widget->update_control(
				$update_control_id,
				[
					'condition' => [
						'_skin!' => [ 'card-hellix', 'hellix-style-2', 'hellix-style-3' ],
					],
				]
			);
		}

		$widget->add_control(
			'icon_heading_title',
			[
				'label' => esc_html__( 'Title', 'hellix-elementor' ),
				'type'  => Controls_Manager::HEADING,
			],
			[
				'position' => [
					'at' => 'before',
					'of' => 'title_bottom_space',
				],
			]
		);

		$widget->add_control(
			'title_css',
			[
				'label'       => esc_html__( 'Title Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Applied to title wrapper', 'hellix-elementor' ),
				'classes'     => 'elementor-control-direction-ltr',

			],
			[
				'position' => [
					'at' => 'before',
					'of' => 'heading_description',
				],
			]
		);

		$widget->add_control(
			'description_css',
			[
				'label'       => esc_html__( 'Description Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Applied to description wrapper', 'hellix-elementor' ),
				'classes'     => 'elementor-control-direction-ltr',

			]
		);

		$widget->add_control(
			'heading_number',
			[
				'label'     => esc_html__( 'Number', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [ '_skin' => 'hellix-style-2' ],
			]
		);

		$widget->add_control(
			'number_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .number__color' => 'fill: {{VALUE}}; color: {{VALUE}}!important;',
				],
				'condition' => [ '_skin' => 'hellix-style-2' ],
			]
		);

		$widget->add_control(
			'number_css',
			[
				'label'       => esc_html__( 'Number Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'hellix-elementor' ),
				'description' => esc_html__( 'Applied to number wrapper', 'hellix-elementor' ),
				'condition'   => [ '_skin' => 'hellix-style-2' ],

			]
		);

		$widget->add_control(
			'heading_button',
			[
				'label'     => esc_html__( 'Button', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [ '_skin!' => 'hellix-style-2' ],
			]
		);

		$widget->add_control(
			'button_type',
			[
				'label'     => esc_html__( 'Type', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'simple',
				'options'   => [
					'simple'    => esc_html__( 'Simple', 'hellix-elementor' ),
					'white'     => esc_html__( 'White', 'hellix-elementor' ),
					'dark'      => esc_html__( 'Dark', 'hellix-elementor' ),
					'secondary' => esc_html__( 'Secondary', 'hellix-elementor' ),
					'accent'    => esc_html__( 'Accent', 'hellix-elementor' ),
					'grey'      => esc_html__( 'Grey', 'hellix-elementor' ),
				],
				'condition' => [
					'_skin!' => [ 'hellix-style-2' ],
				],
			]
		);

		$widget->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'btn_typography',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_ACCENT,
				],
				'selector'  => '{{WRAPPER}} .button__text_color !important;',
				'condition' => [
					'_skin!' => [ 'hellix-style-2' ],
				],
			]
		);

		$widget->add_control(
			'button_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .button__text_color' => 'fill: {{VALUE}}; color: {{VALUE}};',
				],
				'condition' => [ '_skin!' => 'hellix-style-2' ],
			]
		);

		$widget->add_control(
			'button_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .masthead__button' => 'background-color:{{VALUE}} !important;',
					'{{WRAPPER}} .button'           => 'background-color:{{VALUE}} !important;',
					'{{WRAPPER}} .button-color'     => 'background-color:{{VALUE}} !important;',
				],
				'condition' => [ '_skin!' => 'hellix-style-2' ],
			]
		);
	}

	/**
	 * Init Icon Box skins.
	 *
	 * @param \Elementor\Widget_Base $widget The Icon Box Widget.
	 *
	 * @return void
	 */
	public function init_skins( $widget ) {
		$widget->add_skin( new Skins\Skin_Icon_Box_Style_1( $widget ) );
		$widget->add_skin( new Skins\Skin_Icon_Box_Style_2( $widget ) );
		$widget->add_skin( new Skins\Skin_Icon_Box_Style_3( $widget ) );
	}

	/**
	 * Return the name of the module.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-icon-box';
	}

}
