<?php
namespace HellixElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Widget_Base;
use Elementor\Skin_Base as Elementor_Skin_Base;
use HellixElementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The Post Style 2.
 */
class Skin_Posts_Style_2 extends Skin_Base {
	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hellix-posts-v2';
	}
	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Posts v2', 'hellix-elementor' );
	}

	/**
	 * Register Controls Action.
	 */
	protected function _register_controls_actions() {
		parent::_register_controls_actions();

		add_action( 'elementor/element/hx-posts/section_layout/before_section_end', [ $this, 'remove_controls' ], 20 );
		add_action( 'elementor/element/hx-posts/section_query/after_section_end', [ $this, 'modifying_style_sections' ], 30 );
	}
	/** Remove Controls. */
	public function remove_controls() {

		$disable_controls = [
			'show_excerpt',
			'excerpt_length',
			'columns',
			'thumbnail',
			'item_ratio',
			'image_width',
			'thumbnail_size',
			'meta_separator',
			'open_new_tab',
			'masonry',
		];

		foreach ( $disable_controls as $control ) {
			$this->update_control(
				$control,
				[
					'condition' => [
						'_skin!' => 'hellix-posts-v2',
					],
				]
			);
		}

	}

	/**
	 * Modifying the style sections.
	 */
	public function modifying_style_sections() {

		$disable_controls = [
			'heading_excerpt_style',
			'excerpt_color',
			'excerpt_spacing',
			'excerpt_typography_typography',
			'meta_separator_color',
			'section_design_image',
			'section_design_layout',
		];

		foreach ( $disable_controls as $control ) {
			$this->update_control(
				$control,
				[
					'condition' => [
						'_skin!' => [ 'hellix-posts-v2' ],
					],
				]
			);
		}
	}

	/**
	 * Render the link.
	 */
	protected function render_link() { ?>
		<a data-barba href="<?php echo esc_url( $this->current_permalink ); ?>">
		<?php
	}

	/**
	 * Render Post Header.
	 */
	protected function render_post_header() {
		?>
		<div class="col-lg-4 col-md-6 hx-article">
			<div data-anim="img-right cover-black" class="blog -hover">
				<?php
				// $this->render_link();
	}

	/**
	 * Render Post Footer.
	 */
	protected function render_post_footer() {
		?>
			</div>
		</div>
		<?php
	}

	/**
	 * Hellix Render Thumbnail.
	 *
	 * @param  int $index the index number.
	 */
	protected function hellix_render_thumbnail( $index ) {
		$settings                 = $this->parent->get_settings();
		$setting_key              = $this->get_control_id( 'thumbnail_size' );
		$settings[ $setting_key ] = [
			'id' => get_post_thumbnail_id(),
		];
		$thumbnail_html           = Group_Control_Image_Size::get_attachment_image_html( $settings, $setting_key );

		if ( empty( $thumbnail_html ) ) {
			return;
		}

		$thumbnail_classes = 'ratio-img h-100';
		$thumbnail_html    = str_replace( 'class="', 'class="' . $thumbnail_classes . ' ', $thumbnail_html );

		?>
			<div class="ratio ratio-41:35">
				<?php echo wp_kses_post( $thumbnail_html ); ?>
			</div>
		   <?php
	}
	/** Render the category. */
	protected function render_categeory() {
		$taxonomy = 'category';
		if ( empty( $taxonomy ) ) {
			return;
		}

		$terms = get_the_terms( get_the_ID(), $taxonomy );
		if ( empty( $terms[0] ) ) {
			return;
		}

		$term_link = get_term_link( $terms[0] );

		?>
				<div class="blog__category">
					<?php echo wp_kses_post( $terms[0]->name ); ?>
				</div>
		<?php
	}

	/** Render the Category.
	 *
	 * @param  int $index the number.
	 */
	protected function render_content_image( $index ) {
		$this->render_link();
		?>
			<div class="blog__image">
				<?php
				$this->hellix_render_thumbnail( $index );
				$this->render_categeory();
				?>
			</div>
		</a>
		<?php
	}

	/** Render the Title. */
	protected function render_title() {
		$widget        = $this->parent;
		$settings      = $widget->get_settings();
		$tag           = $this->get_instance_value( 'title_tag' );
		$light_version = $this->get_instance_value( 'light_version' );
		$light_class   = 'yes' === $light_version ? ' text-white' : ' text-black';

		if ( ! $this->get_instance_value( 'show_title' ) ) {
			return;
		}

		$this->parent->add_render_attribute( 'post_title', 'class', [ 'hellix-post__title', 'blog__title', 'text-black' ] );

		if ( ! $this->get_instance_value( 'show_title' ) ) {
			return;
		}
		?>
		<<?php echo esc_attr( $tag ); ?> <?php $this->parent->print_render_attribute_string( 'post_title' ); ?>>
		<?php the_title(); ?>
		</<?php echo esc_attr( $tag ); ?>>
		<?php
	}
	/** Render the Post body. */
	protected function render_post_body() {
		$widget        = $this->parent;
		$settings      = $widget->get_settings();
		$light_version = $this->get_instance_value( 'light_version' );
		?>
		<div class="blog__content px-40 py-30 sm:px-24 sm:py-24 bg-white">
			<div class="blog__info">
				<?php $this->render_meta_data(); ?>
			</div>
			<?php
			$this->render_title();
			$this->render_read_more();
			?>
		</div>
		<?php
	}

	/**
	 * Render the Read More.
	 */
	protected function render_read_more() {
		$widget        = $this->parent;
		$settings      = $widget->get_settings();
		$light_version = $this->get_instance_value( 'light_version' );

		if ( ! $this->get_instance_value( 'show_read_more' ) ) {
			return;
		}

		$optional_attributes_html = $this->get_optional_link_attributes_html();
		?>
		
		<a class="hellix-post__text hellix-post__read-more blog__button button -simple <?php echo esc_attr( 'yes' === $light_version ? ' text-beige-dark' : 'text-black' ); ?>" href="<?php the_permalink(); ?>" <?php echo wp_kses_post( $optional_attributes_html ); ?>>
			<?php echo esc_html( $this->get_instance_value( 'read_more_text' ) ); ?>
		</a>
		<?php
	}

	/**
	 * Render the Hellix Post.
	 *
	 * @param  int $index the number.
	 */
	protected function hellix_render_post( $index ) {
		$this->render_post_header();
		// $this->hellix_render_thumbnail( $index );
		// $this->render_categeory();
		$this->render_content_image( $index );
		$this->render_post_body();
		// $this->render_title();
		// $this->render_read_more();
		$this->render_post_footer();

	}

	/** Render the loop header. */
	protected function render_loop_header() {

		?>
		 <div class="row y-gap-32 layout-pt-sm elementor-posts-container">
		<?php
	}

	/** Render the loop footer. */
	protected function render_loop_footer() {
		?>
		</div> 
		<?php
		$this->parent->hellix_pagination();
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$this->parent->query_posts();

		$query = $this->parent->get_query();

		if ( ! $query->found_posts ) {
			return;
		}

		$this->render_loop_header();
		$index = 0;

		// It's the global `wp_query` it self. and the loop was started from the theme.
		if ( $query->in_the_loop ) {
			$this->current_permalink = get_permalink();
			$this->hellix_render_post( $index );
			$index++;
		} else {
			while ( $query->have_posts() ) {
				$query->the_post();
				$this->current_permalink = get_permalink();
				$this->hellix_render_post( $index );
				$index++;
			}
		}
		wp_reset_postdata();
		$this->render_loop_footer();
	}
}
