<?php
namespace HellixElementor\Modules\PriceTable\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use HellixElementor\Base\Base_Widget;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Price Table.
 */
class Price_Table extends Base_Widget {

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'hx-price-table';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Price Table', 'hellix-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-price-table';
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 2.1.0
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'pricing', 'table', 'product', 'image', 'plan', 'button' ];
	}

	/**
	 * Price Table Controls.
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_header',
			[
				'label' => esc_html__( 'Header', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'   => esc_html__( 'Title', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Enter your title', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'sub_heading',
			[
				'label'   => esc_html__( 'Description', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Enter your description', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'heading_tag',
			[
				'label'   => esc_html__( 'Title HTML Tag', 'hellix-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
				],
				'default' => 'h4',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_pricing',
			[
				'label' => esc_html__( 'Pricing', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'currency_symbol',
			[
				'label'   => esc_html__( 'Currency Symbol', 'hellix-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					''             => esc_html__( 'None', 'hellix-elementor' ),
					'dollar'       => '&#36; ' . _x( 'Dollar', 'Currency Symbol', 'hellix-elementor' ),
					'euro'         => '&#128; ' . _x( 'Euro', 'Currency Symbol', 'hellix-elementor' ),
					'baht'         => '&#3647; ' . _x( 'Baht', 'Currency Symbol', 'hellix-elementor' ),
					'franc'        => '&#8355; ' . _x( 'Franc', 'Currency Symbol', 'hellix-elementor' ),
					'guilder'      => '&fnof; ' . _x( 'Guilder', 'Currency Symbol', 'hellix-elementor' ),
					'krona'        => 'kr ' . _x( 'Krona', 'Currency Symbol', 'hellix-elementor' ),
					'lira'         => '&#8356; ' . _x( 'Lira', 'Currency Symbol', 'hellix-elementor' ),
					'peseta'       => '&#8359 ' . _x( 'Peseta', 'Currency Symbol', 'hellix-elementor' ),
					'peso'         => '&#8369; ' . _x( 'Peso', 'Currency Symbol', 'hellix-elementor' ),
					'pound'        => '&#163; ' . _x( 'Pound Sterling', 'Currency Symbol', 'hellix-elementor' ),
					'real'         => 'R$ ' . _x( 'Real', 'Currency Symbol', 'hellix-elementor' ),
					'ruble'        => '&#8381; ' . _x( 'Ruble', 'Currency Symbol', 'hellix-elementor' ),
					'rupee'        => '&#8360; ' . _x( 'Rupee', 'Currency Symbol', 'hellix-elementor' ),
					'indian_rupee' => '&#8377; ' . _x( 'Rupee (Indian)', 'Currency Symbol', 'hellix-elementor' ),
					'shekel'       => '&#8362; ' . _x( 'Shekel', 'Currency Symbol', 'hellix-elementor' ),
					'yen'          => '&#165; ' . _x( 'Yen/Yuan', 'Currency Symbol', 'hellix-elementor' ),
					'won'          => '&#8361; ' . _x( 'Won', 'Currency Symbol', 'hellix-elementor' ),
					'custom'       => esc_html__( 'Custom', 'hellix-elementor' ),
				],
				'default' => 'dollar',
			]
		);

		$this->add_control(
			'currency_symbol_custom',
			[
				'label'     => esc_html__( 'Custom Symbol', 'hellix-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'condition' => [
					'currency_symbol' => 'custom',
				],
			]
		);

		$this->add_control(
			'price',
			[
				'label'   => esc_html__( 'Price', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '59',
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'currency_format',
			[
				'label'   => esc_html__( 'Currency Format', 'hellix-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					''  => '1,234.56 (Default)',
					',' => '1.234,56',
				],
			]
		);

		$this->add_control(
			'sale',
			[
				'label'     => esc_html__( 'Sale', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'On', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Off', 'hellix-elementor' ),
				'default'   => '',
			]
		);

		$this->add_control(
			'original_price',
			[
				'label'     => esc_html__( 'Original Price', 'hellix-elementor' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => '59',
				'condition' => [
					'sale' => 'yes',
				],
				'dynamic'   => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'original_price_annual',
			[
				'label'     => esc_html__( 'Original Annual Price', 'hellix-elementor' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => '659',
				'condition' => [
					'sale'        => 'yes',
					'show_annual' => 'true',
				],
				'dynamic'   => [
					'active' => true,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_features',
			[
				'label' => esc_html__( 'Features', 'hellix-elementor' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_text',
			[
				'label'   => esc_html__( 'Text', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'List Item', 'hellix-elementor' ),
			]
		);

		$default_icon = [
			'value'   => '',
			'library' => 'fa-regular',
		];

		$this->add_control(
			'features_list',
			[
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'item_text' => esc_html__( 'List Item #1', 'hellix-elementor' ),

					],
					[
						'item_text' => esc_html__( 'List Item #2', 'hellix-elementor' ),

					],
					[
						'item_text' => esc_html__( 'List Item #3', 'hellix-elementor' ),

					],
				],
				'title_field' => '{{{ item_text }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_footer',
			[
				'label' => esc_html__( 'Footer', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'   => esc_html__( 'Button Text', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Click Here', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Link', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'default'     => [
					'url' => '#',
				],
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'button_css_id',
			[
				'label'       => esc_html__( 'Button ID', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'default'     => '',
				'title'       => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'hellix-elementor' ),
				'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'hellix-elementor' ),
				'separator'   => 'before',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_badge',
			[
				'label' => esc_html__( 'Badge', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'show_badge',
			[
				'label'     => esc_html__( 'Show', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'yes',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'badge_title',
			[
				'label'     => esc_html__( 'Title', 'hellix-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => esc_html__( 'MOST POPULAR', 'hellix-elementor' ),
				'condition' => [
					'show_badge' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_table_style',
			[
				'label' => esc_html__( 'Table', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'warpper_css',
			[
				'label'       => esc_html__( 'Wrapper CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'py-60',
				'description' => esc_html__( 'Applied to price table wrapper css', 'hellix-elementor' ),

			]
		);

		$this->add_control(
			'enable_border',
			[
				'label'     => esc_html__( 'Enable Border ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'hellix-elementor' ),
				'label_off' => esc_html__( 'No', 'hellix-elementor' ),
				'default'   => 'no',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_header_style',
			[
				'label'      => esc_html__( 'Header', 'hellix-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$this->add_control(
			'heading_heading_style',
			[
				'label'     => esc_html__( 'Title', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__heading' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'heading_typography',
				'selector' => '{{WRAPPER}} .hellix-price-table__heading',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
				],
			]
		);

		$this->add_control(
			'title_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to title content', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'heading_sub_heading_style',
			[
				'label'     => esc_html__( 'Sub Title', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'sub_text_white',
			[
				'label'     => esc_html__( 'Text White ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'hellix-elementor' ),
				'label_off' => esc_html__( 'No', 'hellix-elementor' ),
				'default'   => 'no',
			]
		);

		$this->add_control(
			'sub_heading_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__subheading' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'sub_heading_typography',
				'selector' => '{{WRAPPER}} .hellix-price-table__subheading',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
			]
		);

		$this->add_control(
			'sub_heading_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to title content', 'hellix-elementor' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_pricing_element_style',
			[
				'label'      => esc_html__( 'Pricing', 'hellix-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$this->add_control(
			'text_white',
			[
				'label'     => esc_html__( 'Text White ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'hellix-elementor' ),
				'label_off' => esc_html__( 'No', 'hellix-elementor' ),
				'default'   => 'no',
			]
		);

		$this->add_control(
			'price_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__currency, {{WRAPPER}} .hellix-price-table__integer-part, {{WRAPPER}} .priceCard__price' => 'color: {{VALUE}}',
				],
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'price_typography',
				'selector' => '{{WRAPPER}} .hellix-price-table__price',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
				],
			]
		);

		$this->add_control(
			'heading_original_price_style',
			[
				'label'     => esc_html__( 'Original Price', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'sale'            => 'yes',
					'original_price!' => '',
				],
			]
		);

		$this->add_control(
			'original_price_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_SECONDARY,
				],
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__original-price' => 'color: {{VALUE}}',
				],
				'condition' => [
					'sale'            => 'yes',
					'original_price!' => '',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'original_price_typography',
				'selector'  => '{{WRAPPER}} .hellix-price-table__original-price',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
				],
				'condition' => [
					'sale'            => 'yes',
					'original_price!' => '',
				],
			]
		);

		$this->add_control(
			'original_price_vertical_position',
			[
				'label'                => esc_html__( 'Vertical Position', 'hellix-elementor' ),
				'type'                 => Controls_Manager::CHOOSE,
				'options'              => [
					'top'    => [
						'title' => esc_html__( 'Top', 'hellix-elementor' ),
						'icon'  => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => esc_html__( 'Middle', 'hellix-elementor' ),
						'icon'  => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => esc_html__( 'Bottom', 'hellix-elementor' ),
						'icon'  => 'eicon-v-align-bottom',
					],
				],
				'selectors_dictionary' => [
					'top'    => 'flex-start',
					'middle' => 'center',
					'bottom' => 'flex-end',
				],
				'default'              => 'bottom',
				'selectors'            => [
					'{{WRAPPER}} .hellix-price-table__original-price' => 'align-self: {{VALUE}}',
				],
				'condition'            => [
					'sale'            => 'yes',
					'original_price!' => '',
				],
			]
		);

		$this->add_control(
			'heading_period_style',
			[
				'label'     => esc_html__( 'Period', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'period!' => '',
				],
			]
		);

		$this->add_control(
			'period_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_SECONDARY,
				],
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__period' => 'color: {{VALUE}}',
				],
				'condition' => [
					'period!' => '',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'period_typography',
				'selector'  => '{{WRAPPER}} .hellix-price-table__period',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
				'condition' => [
					'period!' => '',
				],
			]
		);

		$this->add_control(
			'period_position',
			[
				'label'       => esc_html__( 'Position', 'hellix-elementor' ),
				'type'        => Controls_Manager::SELECT,
				'label_block' => false,
				'options'     => [
					'below'  => esc_html__( 'Below', 'hellix-elementor' ),
					'beside' => esc_html__( 'Beside', 'hellix-elementor' ),
				],
				'default'     => 'below',
				'condition'   => [
					'period!' => '',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_features_list_style',
			[
				'label'      => esc_html__( 'Features', 'hellix-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$this->add_control(
			'feat_text_white',
			[
				'label'     => esc_html__( 'Text White ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'hellix-elementor' ),
				'label_off' => esc_html__( 'No', 'hellix-elementor' ),
				'default'   => 'no',
			]
		);

		$this->add_control(
			'features_list_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__features-list' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'features_list_typography',
				'selector' => '{{WRAPPER}} .hellix-price-table__features-list li',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'features_list_alignment',
			[
				'label'     => esc_html__( 'Alignment', 'hellix-elementor' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => esc_html__( 'Left', 'hellix-elementor' ),
						'icon'  => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'hellix-elementor' ),
						'icon'  => 'eicon-text-align-center',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'hellix-elementor' ),
						'icon'  => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__features-list' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_footer_style',
			[
				'label'      => esc_html__( 'Footer', 'hellix-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$this->add_control(
			'heading_footer_button',
			[
				'label'     => esc_html__( 'Button', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'button_text!' => '',
				],
			]
		);

		$this->add_control(
			'button_type',
			[
				'label'     => esc_html__( 'Type', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'dark',
				'options'   => [
					'white'     => esc_html__( 'White', 'hellix-elementor' ),
					'dark'      => esc_html__( 'Dark', 'hellix-elementor' ),
					'secondary' => esc_html__( 'Secondary', 'hellix-elementor' ),
					'accent'    => esc_html__( 'Accent', 'hellix-elementor' ),
					'grey'      => esc_html__( 'Grey', 'hellix-elementor' ),
				],
				'condition' => [
					'button_text!' => '',
				],
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label'     => esc_html__( 'Normal', 'hellix-elementor' ),
				'condition' => [
					'button_text!' => '',
				],
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_ACCENT,
				],
				'selector' => '{{WRAPPER}} .hellix-price-table__button',
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label'     => esc_html__( 'Background Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_ACCENT,
				],
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__button' => 'background-color: {{VALUE}} !important;',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label'     => esc_html__( 'Hover', 'hellix-elementor' ),
				'condition' => [
					'button_text!' => '',
				],
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__button:hover' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_control(
			'button_background_hover_color',
			[
				'label'     => esc_html__( 'Background Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__button:hover' => 'background-color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_control(
			'button_hover_animation',
			[
				'label' => esc_html__( 'Animation', 'hellix-elementor' ),
				'type'  => Controls_Manager::HOVER_ANIMATION,
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'heading_additional_info',
			[
				'label'     => esc_html__( 'Additional Info', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'footer_additional_info!' => '',
				],
			]
		);

		$this->add_control(
			'additional_info_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__additional_info' => 'color: {{VALUE}}',
				],
				'condition' => [
					'footer_additional_info!' => '',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'additional_info_typography',
				'selector'  => '{{WRAPPER}} .hellix-price-table__additional_info',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
				'condition' => [
					'footer_additional_info!' => '',
				],
			]
		);

		$this->add_control(
			'additional_info_margin',
			[
				'label'      => esc_html__( 'Margin', 'hellix-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'default'    => [
					'top'    => 15,
					'right'  => 30,
					'bottom' => 0,
					'left'   => 30,
					'unit'   => 'px',
				],
				'selectors'  => [
					'{{WRAPPER}} .hellix-price-table__additional_info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
				'condition'  => [
					'footer_additional_info!' => '',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_badge_style',
			[
				'label'      => esc_html__( 'Badge', 'hellix-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition'  => [
					'show_badge' => 'yes',
				],
			]
		);

		$this->add_control(
			'badge_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_ACCENT,
				],
				'default'   => '#b8b2fd',
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__badge-inner' => 'background-color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_control(
			'badge_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .hellix-price-table__badge-inner' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'badge_typography',
				'selector' => '{{WRAPPER}} .hellix-price-table__badge-inner',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_ACCENT,
				],
			]
		);

		$this->end_controls_section();
	}
	/**
	 * Render currency symbol.
	 *
	 * @param  [type] $symbol   The symbol name for the currency.
	 * @param  [type] $location The Location.
	 */
	private function render_currency_symbol( $symbol, $location ) {
		$currency_position = $this->get_settings( 'currency_position' );
		$location_setting  = ! empty( $currency_position ) ? $currency_position : 'before';
		if ( ! empty( $symbol ) && $location === $location_setting ) {
			echo wp_kses_post( '<span class="hellix-price-table__currency priceCard__price text-center text-5xl text-white fw-400 mt-8--' . $location . '">' . $symbol . '</span>' );
		}
	}

	/**
	 * Get the currency symbol.
	 *
	 * @param string $symbol_name The symbol name for the currency.
	 * @return string
	 */
	private function get_currency_symbol( $symbol_name ) {
		$symbols = [
			'dollar'       => '&#36;',
			'euro'         => '&#128;',
			'franc'        => '&#8355;',
			'pound'        => '&#163;',
			'ruble'        => '&#8381;',
			'shekel'       => '&#8362;',
			'baht'         => '&#3647;',
			'yen'          => '&#165;',
			'won'          => '&#8361;',
			'guilder'      => '&fnof;',
			'peso'         => '&#8369;',
			'peseta'       => '&#8359',
			'lira'         => '&#8356;',
			'rupee'        => '&#8360;',
			'indian_rupee' => '&#8377;',
			'real'         => 'R$',
			'krona'        => 'kr',
		];

		return isset( $symbols[ $symbol_name ] ) ? $symbols[ $symbol_name ] : '';
	}

	/**
	 * Render the widget in the frontend.
	 */
	protected function render() {
		$settings       = $this->get_settings_for_display();
		$enable_border  = $settings['enable_border'];
		$sub_text_white = $settings['sub_text_white'];
		$desc_css       = $settings['sub_heading_css'];
		$wrapper_css    = $settings['warpper_css'];
		$title_css      = $settings['title_css'];
		$btn_type       = '-' . $settings['button_type'];
		$sub_text_class = 'yes' === $sub_text_white ? ' text-white' : 'text-dark';
		$dark           = 'yes' === $enable_border ? ' border-dark' : 'bg-dark';

		$this->add_render_attribute(
			'button_text',
			'class',
			[
				'hellix-price-table__button btn button ' . $btn_type . ' col-12 -md',
			]
		);

		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button_text', $settings['link'] );
		}

		if ( ! empty( $settings['button_hover_animation'] ) ) {
			$this->add_render_attribute( 'button_text', 'class', 'elementor-animation-' . $settings['button_hover_animation'] );
		}

		$this->add_render_attribute( 'heading', 'class', [ 'hellix-price-table__heading mb-1', 'priceCard__title text-center text-beige-dark text-lg', ' fw-500 ' . $title_css ] );
		$this->add_render_attribute( 'sub_heading', 'class', [ 'hellix-price-table__subheading ' . $sub_text_class, 'mt-24 ' . $desc_css ] );
		$this->add_render_attribute( 'footer_additional_info', 'class', 'hellix-price-table__additional_info' );
		$this->add_render_attribute( 'wrapper_css', 'class', $dark . ' priceCard px-48 ' . $wrapper_css );

		$this->add_inline_editing_attributes( 'heading', 'none' );
		$this->add_inline_editing_attributes( 'sub_heading', 'none' );
		$this->add_inline_editing_attributes( 'footer_additional_info' );
		$this->add_inline_editing_attributes( 'button_text' );

		?>

		 <div <?php $this->print_render_attribute_string( 'wrapper_css' ); ?>>
			  <div class="priceCard__content">
			  <?php
				$this->render_header( $settings );
				$this->render_badge( $settings );
				$this->render_features( $settings );
				$this->render_footer( $settings );
				?>
			</div>
		</div>
		<?php
	}

	/**
	 * Render header.
	 *
	 * @param array $settings The Widget settings.
	 */
	public function render_header( $settings ) {
		$settings       = $this->get_settings_for_display();
		$heading_tag    = $settings['heading_tag'];
		$sub_text_white = $settings['sub_text_white'];

		if ( $settings['heading'] || $settings['sub_heading'] ) :
			?>

			<?php if ( ! empty( $settings['heading'] ) ) : ?>
				<<?php echo esc_attr( $heading_tag ); ?> <?php $this->print_render_attribute_string( 'heading' ); ?>>
				<?php echo wp_kses_post( $settings['heading'] ); ?>
				</<?php echo esc_attr( $heading_tag ); ?>>
				<?php
			endif;

			$this->render_price( $settings );

			if ( ! empty( $settings['sub_heading'] ) ) :
				?>
				<p <?php $this->print_render_attribute_string( 'sub_heading' ); ?>><?php echo wp_kses_post( $settings['sub_heading'] ); ?></p>
			<?php endif; ?>
			<?php
		endif;
	}

	/**
	 * Render Badge.
	 *
	 * @param array $settings The Widget settings.
	 */
	public function render_badge( $settings ) {
		$settings = $this->get_settings_for_display();
		if ( 'yes' === $settings['show_badge'] && ! empty( $settings['badge_title'] ) ) :
			?>
				<div class="priceCard__badge">
					<?php echo wp_kses_post( $settings['badge_title'] ); ?>
				</div>
	   
			<?php
		endif;

	}

	/**
	 * Render Price.
	 *
	 * @param array $settings The Widget settings.
	 */
	public function render_price( $settings ) {
		$settings   = $this->get_settings_for_display();
		$symbol     = '';
		$text_white = $settings['text_white'];

		if ( ! empty( $settings['currency_symbol'] ) ) {
			if ( 'custom' !== $settings['currency_symbol'] ) {
				$symbol = $this->get_currency_symbol( $settings['currency_symbol'] );
			} else {
				$symbol = $settings['currency_symbol_custom'];
			}
		}

		$currency_format = empty( $settings['currency_format'] ) ? '.' : $settings['currency_format'];
		$price           = explode( $currency_format, $settings['price'] );
		$period_position = $settings['period_position'];
		?>
	   
			 <?php if ( 'yes' === $settings['sale'] && ! empty( $settings['original_price'] ) ) : ?>
				<span class="hellix-price-table__original-price elementor-typo-excluded"><?php echo wp_kses_post( $symbol . $settings['original_price'] ); ?></span>
			<?php endif; ?>
				<h3 class="priceCard__price text-center text-5xl <?php echo esc_attr( 'yes' === $text_white ? ' text-white' : 'text-black' ); ?> fw-400 mt-8">
					 <?php echo wp_kses_post( $symbol . $settings['price'] ); ?> 
				</h3>
				
			 <?php if ( ( ! empty( $settings['period'] ) && 'beside' === $period_position ) ) : ?>
			   
					<?php if ( ! empty( $settings['period'] ) && 'beside' === $period_position ) : ?>
						<?php echo wp_kses_post( $period_element ); ?>
					<?php endif; ?>
				</span>
			<?php endif; ?>

			 <?php
				if ( ! empty( $settings['period'] ) && 'below' === $period_position ) :
					echo wp_kses_post( $period_element );
			  endif;
	}

	/**
	 * Render Features.
	 *
	 * @param array $settings The Widget settings.
	 */
	public function render_features( $settings ) {
		 $migration_allowed = Icons_Manager::is_migration_allowed();
		 $feat_text_white   = $settings['feat_text_white'];

		if ( empty( $settings['features_list'] ) ) {
			return;
		}
		?>
		
		<ul class="hellix-price-table__features-list priceCard__list <?php echo esc_attr( 'yes' === $feat_text_white ? ' text-white' : '' ); ?> mt-48">
			<?php
			foreach ( $settings['features_list'] as $index => $item ) :
				$repeater_setting_key = $this->get_repeater_setting_key( 'item_text', 'features_list', $index );
				$this->add_inline_editing_attributes( $repeater_setting_key );

				?>
				<li class="elementor-repeater-item-list-item">

					<?php if ( ! empty( $item['item_text'] ) ) : ?>
						<p class=""> 
							<?php echo wp_kses_post( $item['item_text'] ); ?>
						</p>
					<?php endif; ?>
				</li>
			<?php endforeach; ?>
		</ul> 
		<?php
	}


	/**
	 * Render Footer.
	 *
	 * @param array $settings The Widget settings.
	 */
	public function render_footer( $settings ) {

		if ( ! empty( $settings['button_text'] ) ) :

			$this->add_render_attribute(
				'button_text',
				array(
					'data-barba' => '',
				)
			);
			if ( $settings['button_css_id'] ) :
				$this->add_render_attribute(
					'button_text',
					array(
						'id' => $settings['button_css_id'],
					)
				);
			endif;
			?>

			<div class="hellix-price-table__footer priceCard__button mt-48">	
				<a <?php $this->print_render_attribute_string( 'button_text' ); ?>>
					<?php echo wp_kses_post( $settings['button_text'] ); ?> 
				</a>
			</div>
			<?php
	   endif;
	}
}
