<?php
/**
 * Edit account form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-edit-account.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.5.0
 */

defined( 'ABSPATH' ) || exit;

do_action( 'woocommerce_before_edit_account_form' ); ?>

<form class="woocommerce-EditAccountForm edit-account" action="" method="post" <?php do_action( 'woocommerce_edit_account_form_tag' ); ?> >

	<?php do_action( 'woocommerce_edit_account_form_start' ); ?>
	<div class="row x-gap-24 y-gap-40">

		<p class="woocommerce-form-row woocommerce-form-row--first form-row form-row-first col-sm-6">
			<label for="account_first_name" class="mb-0"><?php esc_html_e( 'First name', 'hellix' ); ?>&nbsp;<span class="required">*</span></label>
			<input type="text" class="form-control woocommerce-Input woocommerce-Input--text input-text py-8" name="account_first_name" id="account_first_name" autocomplete="given-name" value="<?php echo esc_attr( $user->first_name ); ?>" />
		</p>
		<p class="woocommerce-form-row woocommerce-form-row--last form-row form-row-last col-sm-6">
			<label for="account_last_name" class="mb-0"><?php esc_html_e( 'Last name', 'hellix' ); ?>&nbsp;<span class="required">*</span></label>
			<input type="text" class="form-control woocommerce-Input woocommerce-Input--text input-text py-8" name="account_last_name" id="account_last_name" autocomplete="family-name" value="<?php echo esc_attr( $user->last_name ); ?>" />
		</p>
		<div class="clear"></div>

		<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide col-12">
			<label for="account_display_name" class="mb-0"><?php esc_html_e( 'Display name', 'hellix' ); ?>&nbsp;<span class="required">*</span></label>
			<input type="text" class="form-control woocommerce-Input woocommerce-Input--text input-text py-8" name="account_display_name" id="account_display_name" value="<?php echo esc_attr( $user->display_name ); ?>" /> <span><em><?php esc_html_e( 'This will be how your name will be displayed in the account section and in reviews', 'hellix' ); ?></em></span>
		</p>
		<div class="clear"></div>

		<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide col-12 mb-5">
			<label for="account_email" class="mb-0"><?php esc_html_e( 'Email address', 'hellix' ); ?>&nbsp;<span class="required">*</span></label>
			<input type="email" class="form-control woocommerce-Input woocommerce-Input--email input-text py-8" name="account_email" id="account_email" autocomplete="email" value="<?php echo esc_attr( $user->user_email ); ?>" />
		</p>
	</div>


	<fieldset>
		<legend><?php esc_html_e( 'Password change', 'hellix' ); ?></legend>

		<div class="row x-gap-24 y-gap-40">
			<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide col-12 mt-3">
				<label for="password_current" class="mb-0"><?php esc_html_e( 'Current password (leave blank to leave unchanged)', 'hellix' ); ?></label>
				<input type="password" class="form-control woocommerce-Input woocommerce-Input--password input-text py-8" name="password_current" id="password_current" autocomplete="off" />
			</p>
			<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide col-12">
				<label for="password_1" class="mb-0"><?php esc_html_e( 'New password (leave blank to leave unchanged)', 'hellix' ); ?></label>
				<input type="password" class="form-control woocommerce-Input woocommerce-Input--password input-text py-8" name="password_1" id="password_1" autocomplete="off" />
			</p>
			<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide col-12">
				<label for="password_2" class="mb-0"><?php esc_html_e( 'Confirm new password', 'hellix' ); ?></label>
				<input type="password" class="form-control woocommerce-Input woocommerce-Input--password input-text py-8" name="password_2" id="password_2" autocomplete="off" />
			</p>
		</div>
	</fieldset>
	<div class="clear"></div>

	<?php do_action( 'woocommerce_edit_account_form' ); ?>

	<p>
		<?php wp_nonce_field( 'save_account_details', 'save-account-details-nonce' ); ?>
		<button type="submit" class="woocommerce-Button button button -md -accent text-white mt-32" name="save_account_details" value="<?php esc_attr_e( 'Save changes', 'hellix' ); ?>"><?php esc_html_e( 'Save changes', 'hellix' ); ?></button>
		<input type="hidden" name="action" value="save_account_details" />
	</p>

	<?php do_action( 'woocommerce_edit_account_form_end' ); ?>
</form>

<?php do_action( 'woocommerce_after_edit_account_form' ); ?>
